'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.bootstrapPlayers = bootstrapPlayers;
exports.strapbootPlayers = strapbootPlayers;
exports.bootstrapDevices = bootstrapDevices;
exports.strapbootDevices = strapbootDevices;
exports.bootstrapSaves = bootstrapSaves;
exports.strapbootSaves = strapbootSaves;
exports.bootstrap = bootstrap;
exports.strapboot = strapboot;
function bootstrapPlayers(database) {
  return database.create('players').then(function () {
    return database.createView('players', {
      views: {
        all: {
          map: 'function(doc) { emit(null, doc) }'
        },
        byDevice: {
          map: 'function(doc) { if (doc.deviceIds.length > 0) { for(var i in doc.deviceIds) { emit(doc.deviceIds[i], doc); } } }'
        }
      }
    });
  });
}

function strapbootPlayers(database) {
  return database.destroy('players');
}

function bootstrapDevices(database) {
  return database.create('devices');
}

function strapbootDevices(database) {
  return database.destroy('devices');
}

function bootstrapSaves(database) {
  return database.create('saves').then(function () {
    return database.createView('saves', {
      views: {
        byGame: {
          map: 'function(doc) { emit(doc.ensemble.gameId, doc); }'
        }
      }
    });
  }).then(function () {
    return database.create('saves_metadata');
  }).then(function () {
    return database.createView('saves_metadata', {
      views: {
        byPlayer: {
          map: 'function(doc) { if (doc.playerIds.length > 0) { for(var i in doc.playerIds) { emit([doc.id, doc.playerIds[i]], doc); } } }'
        },
        byGameAndPlayer: {
          map: 'function(doc) { if (doc.playerIds.length > 0) { for(var i in doc.playerIds) { emit([doc.gameId, doc.playerIds[i]], doc); } } }'
        }
      }
    });
  });
}

function strapbootSaves(database) {
  return database.destroy('saves').then(function () {
    return database.destroy('saves_metadata');
  });
}

function bootstrap(database) {
  return bootstrapSaves(database).then(function () {
    return bootstrapPlayers(database);
  }).then(function () {
    return bootstrapDevices(database);
  });
}

function strapboot(database) {
  return strapbootSaves(database).then(function () {
    return strapbootPlayers(database);
  }).then(function () {
    return strapbootDevices(database);
  });
}